<?php

namespace DigiComp\HetznerDnsApi\Endpoint;

class ValidateZoneFilePlain extends \DigiComp\HetznerDnsApi\Runtime\Client\BaseEndpoint implements \DigiComp\HetznerDnsApi\Runtime\Client\Endpoint
{
    /**
     * Validate a zone file in text/plain format.
     *
     * @param null|string $requestBody 
     */
    public function __construct(?string $requestBody = null)
    {
        $this->body = $requestBody;
    }
    use \DigiComp\HetznerDnsApi\Runtime\Client\EndpointTrait;
    public function getMethod() : string
    {
        return 'POST';
    }
    public function getUri() : string
    {
        return '/zones/file/validate';
    }
    public function getBody(\Symfony\Component\Serializer\SerializerInterface $serializer, $streamFactory = null) : array
    {
        if (is_string($this->body)) {
            return array(array('Content-Type' => array('text/plain')), $this->body);
        }
        return array(array(), null);
    }
    public function getExtraHeaders() : array
    {
        return array('Accept' => array('application/json'));
    }
    /**
     * {@inheritdoc}
     *
     * @throws \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainUnauthorizedException
     * @throws \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainForbiddenException
     * @throws \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainNotFoundException
     * @throws \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainUnprocessableEntityException
     *
     * @return null|\DigiComp\HetznerDnsApi\Model\ZonesFileValidatePostResponse200
     */
    protected function transformResponseBody(string $body, int $status, \Symfony\Component\Serializer\SerializerInterface $serializer, ?string $contentType = null)
    {
        if (is_null($contentType) === false && (200 === $status && mb_strpos($contentType, 'application/json') !== false)) {
            return $serializer->deserialize($body, 'DigiComp\\HetznerDnsApi\\Model\\ZonesFileValidatePostResponse200', 'json');
        }
        if (401 === $status) {
            throw new \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainUnauthorizedException();
        }
        if (403 === $status) {
            throw new \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainForbiddenException();
        }
        if (404 === $status) {
            throw new \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainNotFoundException();
        }
        if (422 === $status) {
            throw new \DigiComp\HetznerDnsApi\Exception\ValidateZoneFilePlainUnprocessableEntityException();
        }
    }
    public function getAuthenticationScopes() : array
    {
        return array('Auth-API-Token');
    }
}